#!/bin/sh

# Copyright (C) 2000-2001 Chris Ross

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies of the Software, its documentation and marketing & publicity
# materials, and acknowledgment shall be given in the documentation, materials
# and software packages that this Software was used.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

NAME="Ferite Module Distributer"
VERSION="0.2"
AUTHOR="Chris Ross <ctr@ferite.org>"

echo "$NAME ($VERSION)"
echo "Copyright (c) 2000-2001 $AUTHOR"
echo 
echo "This software is distributed under the same terms as ferite. Please see"
echo "the file COPYING. Output will be prefixed with 'FMGEN'"
echo

if ! test -f "$1"; then
  echo
  echo "ERROR: ERROR:"
  echo "  Can't build module using $1 - file not found"
  echo 
  exit 1
fi

# Get the modulename
MODULENAME=`basename $1 .fec`
MODULEVERSION=`ferite-config --version`
BUILDER=`which builder`

# Get the directory we are going to build the tarball in
if test -d "$MODULENAME"; then
  echo "FMGEN: Cleaning old $MODULENAME directory away..."
  rm -rf $MODULENAME
fi

echo "FMGEN: Creating module directory..."
mkdir $MODULENAME

# Copy over the skelton tree
echo "FMGEN: Copying skeleton files over..."
cp -rf skel/* $MODULENAME/

# Make the directory for the module
mkdir $MODULENAME/modules/$MODULENAME

# Copy the .fec file over
cp $1 $MODULENAME/modules/$MODULENAME

# Build the modules's c files
echo "FMGEN: Generating C files..."
cd $MODULENAME/modules/$MODULENAME
$BUILDER -m $MODULENAME $MODULENAME".fec"
cd ../../

# Now we sed modify the configure.ac configure.in and modules/Makefile.am
echo "FMGEN: Modifying configuration scripts..."
cat configure.ac.stub | sed -e "s/%mod%/$MODULENAME/g" > configure.ac
rm configure.ac.stub

cat configure.in.stub | sed -e "s/%mod%/$MODULENAME/g" > configure.in
rm configure.in.stub

cat modules/Makefile.am.stub | sed -e "s/%mod%/$MODULENAME/g" > modules/Makefile.am
rm modules/Makefile.am.stub

cat modules/$MODULENAME/Makefile.am | sed -e "s/-L\${top_builddir}\/src//g" > modules/$MODULENAME/Makefile.am.new
rm modules/$MODULENAME/Makefile.am
mv modules/$MODULENAME/Makefile.am.new modules/$MODULENAME/Makefile.am

case "$2" in
   tarball)
     echo "FMGEN: Building tarball..."
	 echo "FMGEN:   Running autotools"
     autoheader
	 aclocal
	 automake --foreign --add-missing
	 autoconf
	 echo "FMGEN:   Building tar archive"
	 cd ..
	 tar -cf $MODULENAME-$MODULEVERSION.tar $MODULENAME
	 echo "FMGEN:   Compressing"
	 gzip $MODULENAME-$MODULEVERSION.tar
	 echo "FMGEN:   Removing directory"
	 rm -rf $MODULENAME
	 ;;
   test)
     echo "FMGEN: Testing tree"
	 echo "FMGEN:   Running autotools"
     autoheader
	 aclocal
	 automake --foreign --add-missing
	 autoconf
	 echo "FMGEN:   Configuring"
	 ./configure
	 echo "FMGEN:   Building"
	 make
	 ;;
   *)
     ;;
esac
